@@ -29,14 +29,6 @@ This WSGI component:
 Refer to: http://docs.openstack.org/developer/keystonemiddleware/\
 middlewarearchitecture.html
 
-Run this module directly to start a protected echo service on port 8000::
-
- $ python -m keystonemiddleware.auth_token
-
-When the ``auth_token`` module authenticates a request, the echo service
-will respond with all the environment variables presented to it by this
-module.
-
 
 Headers
 -------
@@ -174,6 +166,37 @@ keystone.token_auth
     :py:class:`keystoneclient.session.Session`. This plugin will load the
     authentication data provided to auth_token middleware.
 
+
+Configuration
+-------------
+
+Middleware configuration can be in the main application's configuration file,
+e.g. in ``nova.conf``:
+
+.. code-block:: ini
+
+  [keystone_authtoken]
+  auth_plugin = password
+  auth_url = http://keystone:35357/
+  username = nova
+  user_domain_id = default
+  password = whyarewestillusingpasswords
+  project_name = service
+  project_domain_id = default
+
+Configuration can also be in the ``api-paste.ini`` file with the same options,
+but this is discouraged.
+
+Swift
+-----
+
+When deploy Keystone auth_token middleware with Swift, user may elect to use
+Swift memcache instead of the local auth_token memcache. Swift memcache is
+passed in from the request environment and it's identified by the
+``swift.cache`` key. However it could be different, depending on deployment. To
+use Swift memcache, you must set the ``cache`` option to the environment key
+where the Swift cache object is stored.
+
 """
 
 import datetime
@@ -203,24 +226,6 @@ from keystonemiddleware.auth_token import _utils
 from keystonemiddleware.i18n import _, _LC, _LE, _LI, _LW
 
 
-# alternative middleware configuration in the main application's
-# configuration file e.g. in nova.conf
-# [keystone_authtoken]
-# auth_host = 127.0.0.1
-# auth_port = 35357
-# auth_protocol = http
-# admin_tenant_name = admin
-# admin_user = admin
-# admin_password = badpassword
-
-# when deploy Keystone auth_token middleware with Swift, user may elect
-# to use Swift memcache instead of the local auth_token memcache. Swift
-# memcache is passed in from the request environment and its identified by the
-# 'swift.cache' key. However it could be different, depending on deployment.
-# To use Swift memcache, you must set the 'cache' option to the environment
-# key where the Swift cache object is stored.
-
-
 # NOTE(jamielennox): A number of options below are deprecated however are left
 # in the list and only mentioned as deprecated in the help string. This is
 # because we have to provide the same deprecation functionality for arguments
@@ -308,7 +313,7 @@ _OPTS = [
     cfg.IntOpt('memcache_pool_socket_timeout',
                default=3,
                help='(Optional) Socket timeout in seconds for communicating '
-                    'with a memcache server.'),
+                    'with a memcached server.'),
     cfg.IntOpt('memcache_pool_unused_timeout',
                default=60,
                help='(Optional) Number of seconds a connection to memcached'
@@ -316,10 +321,10 @@ _OPTS = [
     cfg.IntOpt('memcache_pool_conn_get_timeout',
                default=10,
                help='(Optional) Number of seconds that an operation will wait '
-                    'to get a memcache client connection from the pool.'),
+                    'to get a memcached client connection from the pool.'),
     cfg.BoolOpt('memcache_use_advanced_pool',
                 default=False,
-                help='(Optional) Use the advanced (eventlet safe) memcache '
+                help='(Optional) Use the advanced (eventlet safe) memcached '
                      'client pool. The advanced pool will only work under '
                      'python 2.x.'),
     cfg.BoolOpt('include_service_catalog',
@@ -686,6 +691,8 @@ class AuthProtocol(object):
             return token
         else:
             if not self._delay_auth_decision:
+                self._LOG.warn(_LW('Unable to find authentication token'
+                                   ' in headers'))
                 self._LOG.debug('Headers: %s', env)
             raise exc.InvalidToken(_('Unable to find token in headers'))
 
@@ -716,12 +723,11 @@ class AuthProtocol(object):
         start_response('401 Unauthorized', resp.headers)
         return resp.body
 
-    def _validate_token(self, token, env, retry=True):
+    def _validate_token(self, token, env):
         """Authenticate user token
 
         :param token: token id
         :param env: wsgi environment
-        :param retry: Ignored, as it is not longer relevant
         :returns: uncrypted body of the token if the token is valid
         :raises exc.InvalidToken: if token is rejected
 
@@ -766,7 +772,7 @@ class AuthProtocol(object):
                     expires = _get_token_expiration(data)
                     _confirm_token_not_expired(expires)
                 else:
-                    data = self._identity_server.verify_token(token, retry)
+                    data = self._identity_server.verify_token(token)
                     # No need to confirm token expiration here since
                     # verify_token fails for expired tokens.
                     expires = _get_token_expiration(data)
@@ -1127,24 +1133,6 @@ def app_factory(global_conf, **local_conf):
     return AuthProtocol(None, conf)
 
 
-if __name__ == '__main__':
-    def echo_app(environ, start_response):
-        """A WSGI application that echoes the CGI environment to the user."""
-        start_response('200 OK', [('Content-Type', 'application/json')])
-        environment = dict((k, v) for k, v in six.iteritems(environ)
-                           if k.startswith('HTTP_X_'))
-        yield jsonutils.dumps(environment)
-
-    from wsgiref import simple_server
-
-    # hardcode any non-default configuration here
-    conf = {'auth_protocol': 'http', 'admin_token': 'ADMIN'}
-    app = AuthProtocol(echo_app, conf)
-    server = simple_server.make_server('', 8000, app)
-    print('Serving on port 8000 (Ctrl+C to end)...')
-    server.serve_forever()
-
-
 # NOTE(jamielennox): Maintained here for public API compatibility.
 InvalidToken = exc.InvalidToken
 ServiceError = exc.ServiceError
