@@ -11,7 +11,6 @@
 # under the License.
 
 import contextlib
-import hashlib
 
 from keystoneclient.common import cms
 from oslo_serialization import jsonutils
@@ -24,22 +23,6 @@ from keystonemiddleware.i18n import _, _LE
 from keystonemiddleware.openstack.common import memorycache
 
 
-def _hash_key(key):
-    """Turn a set of arguments into a SHA256 hash.
-
-    Using a known-length cache key is important to ensure that memcache
-    maximum key length is not exceeded causing failures to validate.
-    """
-    if isinstance(key, six.text_type):
-        # NOTE(morganfainberg): Ensure we are always working with a bytes
-        # type required for the hasher. In python 2.7 it is possible to
-        # get a text_type (unicode). In python 3.4 all strings are
-        # text_type and not bytes by default. This encode coerces the
-        # text_type to the appropriate bytes values.
-        key = key.encode('utf-8')
-    return hashlib.sha256(key).hexdigest()
-
-
 class _CachePool(list):
     """A lazy pool of cache references."""
 
@@ -74,9 +57,9 @@ class _MemcacheClientPool(object):
                  memcache_pool_conn_get_timeout=None,
                  memcache_pool_socket_timeout=None):
         # NOTE(morganfainberg): import here to avoid hard dependency on
-        # python-memcache library.
+        # python-memcached library.
         global _memcache_pool
-        from keystonemiddleware import _memcache_pool
+        from keystonemiddleware.auth_token import _memcache_pool
 
         self._pool = _memcache_pool.MemcacheClientPool(
             memcache_servers,
@@ -234,7 +217,7 @@ class TokenCache(object):
         # NOTE(jamielennox): in the basic implementation there is no need for
         # a context so just pass None as it will only get passed back later.
         unused_context = None
-        return self._CACHE_KEY_TEMPLATE % _hash_key(token_id), unused_context
+        return self._CACHE_KEY_TEMPLATE % token_id, unused_context
 
     def _deserialize(self, data, context):
         """Deserialize data from the cache back into python objects.
